from setuptools import setup, find_packages
import codecs
import os

VERSION = '0.0.1'
DESCRIPTION ='print hello libary trial'

setup(
    name = 'hello_print',
    version=VERSION,
    author='Movin Fernandes',
    author_email='movin.fernandes@hotmail.com',
    description=DESCRIPTION,
    packages=find_packages(),
    install_requires = [],
    keywords=['square','number','trial','test']

)